/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.area;

import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.model.Culture;
import nl.cloudfarming.client.model.Field;
import nl.cloudfarming.client.model.Plot;
import nl.cloudfarming.client.model.PlotFile;

/**
 * interface which described functionality to access plots and related data
 *
 *
 * @author Timon Veenstra
 */
public interface AreaService {


    /**
     * Find a plot file by name and checksum
     *
     * usefull to see if a plot file is already present in the database
     *
     * @param name Name of the plot to find
     * @param checksum Checksum of the plot to find
     * @return The plotfile matching this name and Checksum
     */
    PlotFile findPlotFileByNameChecksum(String name, String checksum);

    /**
     * Retrieve all plots
     *
     * @return A list of all plots
     */
    List<Plot> findAllPlots();

    /**
     * Find all fields valid for a certain date
     *
     * @param date Date on which the fields are active
     * @return The list of fields that are/were active on the specified date.
     */
    List<Field> findFieldsByDate(Date date);

    /**
     * Find all cultures valid for a certain date
     *
     * @param date Date on which the cultures are active
     * @return The list of cultures that are/were active on the specified date.
     */
    List<Culture> findCulturesByDate(Date date);
    

    /**
     * Find a plot by its id
     * 
     * @param id The ID of the Plot to find
     * @return The plot with the specified ID as id
     */
    Plot findPlotById(long id);

    /**
     * Create a new plot with filled model object
     * 
     * @param plot The plot to create
     */
    void createNewPlot(Plot plot);

    /**
     * Create a new plot File object
     * @param plotFile
     */
    void createNewPlotFile(PlotFile plotFile);

    /**
     * Create a new Field
     * @param field Field to create
     */
    void createNewField(Field field);

    /**
     * Saves changes in a plot object, should be an existing object
     * 
     * @param plot Plot to save
     */
    void savePlotChanges(Plot plot);

}
